1.0.0 API documentation: matrix_double3x3.hpp File Reference

| 1.0.0 API documentation

Typedefs
matrix_double3x3.hpp File Reference

Core features More...

Go to the source code of this file.

## Typedefs
typedef mat< 3, 3, double, defaultp > | dmat3
| 3 columns of 3 components matrix of double-precision floating-point numbers. More...
typedef mat< 3, 3, double, defaultp > | dmat3x3
| 3 columns of 3 components matrix of double-precision floating-point numbers. More...

## Detailed Description

Core features

Definition in file matrix_double3x3.hpp.